==> owega-5.6.3-py3-none-any.whl: owega/OweHandlers/handle_model.py <==
"""Handle /model."""
import prompt_toolkit as pt

from ..config import baseConf, list_models
from ..OwegaSession import OwegaSession as ps
from ..utils import clrtxt, info_print


# changes the selected model
def handle_model(
    temp_file,
    messages,
    given="",
    temp_is_temp=False,
    silent=False
):
    """Handle /model.

    Command description:
        List the available models and prompt for change.

    Usage:
        /model [model name/ID]
    """
    given = given.strip()
    if not silent:
        info_print(f"Current model: {baseConf.get('model', '')}")
        list_models()
        print()
    if given:
        new_model = given
    else:
        new_model = ps['model'].prompt(pt.ANSI(
            '\n' + clrtxt("magenta", " new model ") + ': ')).strip()
    if (new_model.isnumeric()):
        if (int(new_model) < len(baseConf.get("available_models", []))):
            mn = int(new_model)
            baseConf["model"] = baseConf.get("available_models", [])[mn]
            if not silent:
                info_print(f"Model changed to {baseConf.get('model', '')}")
        else:
            if not silent:
                info_print(f"Model not available, keeping {baseConf.get('model', '')}")
    elif new_model in list(baseConf.get("available_models", [])):
        baseConf["model"] = new_model
        if not silent:
            info_print(f"Model changed to {baseConf.get('model', '')}")
    else:
        if not silent:
            info_print(f"Model not available, keeping {baseConf.get('model', '')}")
    return messages


item_model = {
    "fun": handle_model,
    "help": "list the available models and prompt for change",
    "commands": ["model"],
}

==> owega-5.9.0-py3-none-any.whl: owega/OweHandlers/handle_model.py <==
"""Handle /model."""
import prompt_toolkit as pt

from ..config import baseConf, list_models
from ..OwegaSession import OwegaSession as ps
from ..utils import clrtxt, info_print


# changes the selected model
def handle_model(
    temp_file,
    messages,
    given="",
    temp_is_temp=False,
    silent=False
):
    """Handle /model.

    Command description:
        List the available models and prompt for change.

    Usage:
        /model [model name/ID]
    """
    given = given.strip()
    if not silent:
        info_print(f"Current model: {baseConf.get('model', '')}")
        list_models()
        print()
    if given:
        new_model = given
    else:
        if ps['model'] is not None:
            new_model = ps['model'].prompt(pt.ANSI(
                '\n' + clrtxt("magenta", " new model ") + ': ')).strip()
        else:
            new_model = input(
                '\n' + clrtxt("magenta", " new model ") + ': ').strip()
    if (new_model.isnumeric()):
        if (int(new_model) < len(baseConf.get("available_models", []))):
            mn = int(new_model)
            baseConf["model"] = baseConf.get("available_models", [])[mn]
            if not silent:
                info_print(f"Model changed to {baseConf.get('model', '')}")
        else:
            if not silent:
                info_print(
                    f"Model not available, keeping {baseConf.get('model', '')}")
    elif new_model in list(baseConf.get("available_models", [])):
        baseConf["model"] = new_model
        if not silent:
            info_print(f"Model changed to {baseConf.get('model', '')}")
    else:
        if not silent:
            info_print(
                f"Model not available, keeping {baseConf.get('model', '')}")
    return messages


item_model = {
    "fun": handle_model,
    "help": "list the available models and prompt for change",
    "commands": ["model"],
}
